<?php
/**
 *	Controls for the Front Page
 *
 *	@package it-photographer
 *
 */
 
function itpg_front_page_customize_register( $wp_customize ) {
	
	$wp_customize->add_panel(
		'itpg_front_page', array(
			'title'			=>	__('Front Page', 'it-photographer'),
			'description'	=>	__('Modules for the Static Front Page.<br/>Will work on Static Front page with Front Page Template set.', 'it-photographer'),
			'priority'		=>	30
		)
	);
	
	$wp_customize->add_section(
		'itpg_hero', array(
			'title'		=>	__('Hero', 'it-photographer'),
			'priority'	=>	5,
			'panel'		=>	'itpg_front_page'
		)
	);
	
	$wp_customize->add_setting(
		'itpg_hero_title', array(
			'default'			=>	__('About Us', 'it-photographer'),
			'sanitize_callback'	=>	'sanitize_text_field'
		)
	);
	
	$wp_customize->add_control(
		'itpg_hero_title', array(
			'label'	=>	__('Title', 'it-photographer'),
			'priority'	=>	5,
			'section'	=>	'itpg_hero'
		)
	);
	
	$wp_customize->add_setting(
		'itpg_hero_page', array(
			'default'	=>	__('About Us', 'it-photographer'),
			'sanitize_callback'		=>	'itpg_sanitize_dropdown_pages'
		)
	);
	
	$wp_customize->add_control(
		'itpg_hero_page', array(
			'label'	=>	__('Page', 'it-photographer'),
			'description'	=>	__('Select the About Us page/The page from which content for this section need to be fetched', 'it-photographer'),
			'type'		=>	'dropdown-pages',
			'priority'	=>	5,
			'section'	=>	'itpg_hero'
		)
	);
	
	if ( class_exists( 'Jetpack_Portfolio' ) ) {
		
		$wp_customize->add_section(
			'itpg_home_portfolio', array(
				'title'			=>	__('Projects', 'it-photographer'),
				'description'	=>	__('Jetpack needs to be installed and Portfolios need to be activated for this section to work', 'it-photographer'),
				'panel'			=> 'itpg_front_page'
			)
		);
		
		$wp_customize->add_setting(
			'itpg_home_portfolio_title', array(
				'default'			=>	__('Our Projects', 'it-photographer'),
				'sanitize_callback'	=>	'sanitize_text_field'
			)
		);
		
		$wp_customize->add_control(
			'itpg_home_portfolio_title', array(
				'label'		=>	__('Title', 'it-photographer'),
				'priority'	=>	5,
				'section'	=>	'itpg_home_portfolio'
			)
		);
		
		for ( $i = 1; $i <= 4; $i++ ) {
			
			$wp_customize->add_setting(
				'itpg_portfolio_' . $i, array(
					'default'		=>	'',
					'sanitize_callback'	=>	'absint'
				)
			);
			
			$wp_customize->add_control(
				new itpg_Portfolio_Select_Control(
					$wp_customize, 'itpg_portfolio_' . $i, array(
						'label'		=>	esc_html('Portfolio ' . $i, 'it-photographer'),
						'section'	=>	'itpg_home_portfolio',
					)
				)
			);
		}
	}
		
	if ( class_exists( 'Jetpack_Testimonial' ) ) {
		
		$wp_customize->add_section(
			'itpg_home_testimonial', array(
				'title'			=>	__('Testimonials', 'it-photographer'),
				'description'	=>	__('Jetpack needs to be installed and Testimonials need to be activated for this section to work', 'it-photographer'),
				'panel'			=> 'itpg_front_page'
			)
		);
		
		$wp_customize->add_setting(
			'itpg_home_testimonial_enable', array(
				'default'	=>	'',
				'sanitize_callback'	=>	'itpg_sanitize_checkbox'
			)
		);
		
		$wp_customize->add_control(
			'itpg_home_testimonial_enable', array(
				'label'		=>	__('Enable Testimonials Section', 'it-photographer'),
				'section'	=>	'itpg_home_testimonial',
				'type'		=>	'checkbox',
				'priority'	=>	5
			)
		);
		
		$wp_customize->add_setting(
			'itpg_home_testimonial_title', array(
				'default'			=>	__('Testimonials', 'it-photographer'),
				'sanitize_callback'	=>	'sanitize_text_field'
			)
		);
		
		$wp_customize->add_control(
			'itpg_home_testimonial_title', array(
				'label'		=>	__('Title', 'it-photographer'),
				'priority'	=>	10,
				'section'	=>	'itpg_home_testimonial'
			)
		);
		
		
		$wp_customize->add_setting(
			'itpg_home_testimonial_count', array(
				'default'			=>	'',
				'sanitize_callback'	=>	'absint'
			)
		);
		
		$wp_customize->add_control(
			'itpg_home_testimonial_count', array(
				'label'		=>	__('Number of Testimonials', 'it-photographer'),
				'priority'	=>	15,
				'section'	=>	'itpg_home_testimonial'
			)
		);
	}
	
	$wp_customize->add_section(
		'itpg_front_blog', array(
			'title'		=>	__('From the Blog', 'it-photographer'),
			'panel'		=>	'itpg_front_page'
		)
	);
	
	$wp_customize->add_setting(
		'itpg_front_blog_enable', array(
			'default'	=>	'',
			'sanitize_callback'	=>	'itpg_sanitize_checkbox'
		)
	);
	
	$wp_customize->add_control(
		'itpg_front_blog_enable', array(
			'label'		=>	__('Enable Blog Section', 'it-photographer'),
			'section'	=>	'itpg_front_blog',
			'type'		=>	'checkbox',
			'priority'	=>	5
		)
	);
	
	$wp_customize->add_setting(
		'itpg_front_blog_title', array(
			'default'			=>	__('From the Blog', 'it-photographer'),
			'sanitize_callback'	=>	'sanitize_text_field'
		)
	);
	
	$wp_customize->add_control(
		'itpg_front_blog_title', array(
			'label'		=>	__('Title', 'it-photographer'),
			'priority'	=>	10,
			'section'	=>	'itpg_front_blog'
		)
	);
}
add_action('customize_register', 'itpg_front_page_customize_register');