<?php
// Register and load the widget
function itpg_featured_cat_widget() {
    register_widget( 'itpg_featured_cat' );
}
add_action( 'widgets_init', 'itpg_featured_cat_widget' );

// Creating the widget
class itpg_featured_cat extends WP_Widget {

    function __construct() {
        parent::__construct(

// Base ID of your widget
            'itpg_featured_cat',

// Widget name will appear in UI
            esc_html__('ITP - Featured Category', 'it-photographer'),

// Widget description
            array( 'description' => esc_html__( 'This Widget will show posts from a selected category.', 'it-photographer' ), )
        );
    }

// Creating widget front-end

    public function widget( $args, $instance ) {

        $title		= apply_filters( 'widget_title', empty( $instance['title'] ) ? __('Trending', 'it-photographer') : $instance['title'], $instance, $this->id_base );
        $post_count	= isset( $instance['post_count'] ) ? $instance['post_count'] : 4;
        $category	= isset( $instance['category'] ) ? $instance['category'] : 0;


                echo $args['before_widget'];
                if ( ! empty( $title ) )
                    echo $args['before_title'] . $title . $args['after_title'];
            
					$widget_args	=	array(
						'cat'					=>	$category,
						'posts_per_page'		=>	$post_count,
						'ignore_sticky_posts'	=>	true
					);
					
					$widget_query	=	new WP_Query( $widget_args );
					
					if ( $widget_query->have_posts() ) : ?>
						<div class="itpg-widget-posts">
						<?php
		            		while ($widget_query->have_posts() ) : $widget_query->the_post(); ?>
			            		<div class=" itp-widget-post no-gutters row">
				            		<div class="itpg-widget-post-thumb col-4">
					            		<?php if ( has_post_thumbnail() ): ?>
											<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail('itpg_square_thumb'); ?></a>
										<?php
										else :
										?>	<a href="<?php the_permalink(); ?>"><img class="wp-post-image" src="<?php echo esc_url(get_template_directory_uri() . '/assets/images/ph_square.png'); ?>"></a>
										<?php endif; ?>
				            		</div>
				            		<div class="itpg-widget-post-title col-8">
					            		<?php the_title( '<div class="entry-title"><a href="' . esc_url( get_permalink() ) . '">', '</a></div>' ); ?>
				            		</div>
			            		</div>
							<?php
							endwhile;
							?>
						</div>
					<?php
					endif;
					wp_reset_postdata();
            
    	   echo $args['after_widget'];

    }

// Widget Backend
    public function form( $instance ) {

        /* Set up some default widget settings. */
       $defaults = array(
           'title'              => __('Trending', 'it-photographer'),
		   'post_count'         => 4,
		   'category'			=> 0
       );
       $instance = wp_parse_args( (array) $instance, $defaults );
         ?>

        <p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><h4><?php _e( 'Title', 'it-photographer' ); ?></h4></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
        </p>


        <p>
            <label for="<?php echo $this->get_field_id( 'post_count' ); ?>"><h4><?php _e( 'Number of Posts', 'it-photographer' ); ?></h4></label>
            <input id="<?php echo $this->get_field_id( 'post_count' ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'post_count' ); ?>" type="number" value="<?php echo esc_attr( $instance['post_count'] ); ?>" />
        </p>
        
        <p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>"><h4><?php _e('Category', 'it-photographer'); ?></h4></label>
			<select id="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'category' ) ); ?>">
				<option value="0" <?php if ( !$instance['category'] ) echo 'selected="selected"'; ?>><?php _e('--None--', 'it-photographer'); ?></option>
				<?php
				$categories = get_categories(array('type' => 'post'));

				foreach( $categories as $cat ) {
					echo '<option value="' . esc_attr( $cat->cat_ID ) . '"';

					if ( $cat->cat_ID == $instance['category'] ) echo  ' selected="selected"';

					echo '>' . esc_html( $cat->cat_name . ' (' . $cat->category_count . ')' );

					echo '</option>';
				}
				?>
			</select>
		</p>

        <?php
    }

    // Updating widget replacing old instances with new
    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title']              =   ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : __('Trending', 'it-photographer');
        $instance['post_count']         =   ( ! empty( $new_instance['post_count'] ) ) ? absint($new_instance['post_count']) : 4;
        $instance['category']         	=   ( ! empty( $new_instance['category'] ) ) ? absint($new_instance['category']) : 0;
        
        return $instance;
    }
}
    