<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package it-photographer
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function itpg_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'itpg_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function itpg_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'itpg_pingback_header' );

/**
 *	Content Wrapper Start
 */
if ( !function_exists('itpg_content_wrapper_start') ) {
	function itpg_content_wrapper_start() { ?>
	
		<div id="content-wrapper">
			
	<?php
	}
}
add_action('itpg_content_wrapper_start', 'itpg_content_wrapper_start', 10);


/**
 *	Content Wrapper Start
 */
if ( !function_exists('itpg_content_wrapper_end') ) {
	function itpg_content_wrapper_end() { ?>
	
		</div><!-- .content-wrapper -->
			
	<?php
	}
}
add_action('itpg_content_wrapper_end', 'itpg_content_wrapper_end', 10);


/**
 *	Pagination
 */
function itpg_get_pagination() {

	$args	=	apply_filters( 'itpg_pagination', array(
		'mid_size' => 2,
		'prev_text' => __( '<i class="fas fa-angle-left"></i>', 'it-photographer' ),
		'next_text' => __( '<i class="fas fa-angle-right"></i>', 'it-photographer' ),
	) );

	the_posts_pagination($args);

}
add_action('itpg_pagination', 'itpg_get_pagination');


/**
 *	Function to generate meta data for the posts
 */
 if ( !function_exists('itpg_get_metadata') ) {
	 
	function itpg_get_metadata() {
		if ( 'post' === get_post_type() ) :
			?>
				<div class="entry-meta">
					<?php
					itpg_posted_by();
					itpg_posted_on();
					itpg_get_post_categories();
					itpg_get_comments();
					?>
				</div>
		<?php endif;
	}
}
add_action('itpg_metadata', 'itpg_get_metadata');

 

/**
 *	Function for post content on Blog Page
 */
 if ( !function_exists( 'itpg_get_blog_excerpt' ) ) {
	 
	 function itpg_get_blog_excerpt( $post = NULL, $length = 30 ) {
	 	
		global $post;
		
		$output	=	'';
		
		if ( isset( $post->ID ) && has_excerpt( $post->ID ) ) {
			
			$output = $post->post_excerpt;
		}
	
		elseif ( isset( $post->post_content ) ) {
			
			if ( strpos($post->post_content, '<!--more-->') ) {
				$output	=	get_the_content('', $post );
			}
			 else {
				
				$output	=	wp_trim_words( strip_shortcodes( $post->post_content ), $length );
			}
		 }
	
		 $output	=	apply_filters('itpg_excerpt', $output);
	
		 echo $output;
	 }
}
 add_action('itpg_blog_excerpt', 'itpg_get_blog_excerpt', 10, 1);


if ( !function_exists('itpg_get_layout') ) {
	function itpg_get_layout( $layout = 'classic' , $count = NULL ) {
		
		$dir	=	'framework/layouts/content';
		 
		get_template_part( $dir, $layout, $count );
		
	}
}
 add_action( 'itpg_layout', 'itpg_get_layout', 10, 2 );


 /**
  *	Function for 'Read More' link
  */
  function itpg_read_more_link() {
	  ?>
	  <div class="read-more title-font"><a href="<?php the_permalink() ?>"><?php apply_filters( 'itpg_read_more', _e('Read More', 'it-photographer') ); ?></a></div>
	  <?php
  }


/**
 *	Function to Enable Sidebar
 */
if ( !function_exists('itpg_get_sidebar') ) {
	function itpg_get_sidebar( $template ) {
	
	   global $post;
	   switch( $template ) {
		    case "blog";
		    if ( is_home() &&
		    	get_theme_mod('itpg_blog_sidebar_enable', 1) !== "" ) {
			    get_sidebar();
			}
			break;
		    case "single":
		   		if( is_single() &&
		   		get_theme_mod('itpg_single_sidebar_enable', 1) !== "" ) {
					get_sidebar('single');
				}
			break;
			case "search":
		   		if( is_search() &&
		   		get_theme_mod('itpg_search_sidebar_enable', 1) !== "" ) {
					get_sidebar();
				}
			break;
			case "archive":
		   		if( is_archive() &&
		   		get_theme_mod('itpg_archive_sidebar_enable', 1) !== "" ) {
					get_sidebar();
				}
			break;
			case "page":
				if	( is_page() &&
				!is_front_page() &&
				'' !== get_post_meta($post->ID, 'enable-sidebar', true) ) {
					get_sidebar('page', ['page'	=>	'page']);
				}
			break;
		    default:
		    	get_sidebar();
		}
	}
}
add_action('itpg_sidebar', 'itpg_get_sidebar', 10, 1);



 /**
  *	Function for Sidebar alignment
  */
if ( !function_exists('itpg_sidebar_align') ) {
	function itpg_sidebar_align( $template = 'blog' ) {
		
		$align = 'page'	== $template ? get_post_meta( get_the_ID(), 'align-sidebar', true ) : get_theme_mod('itpg_' . $template . '_sidebar_layout', 'right');
	
		return $align;
	}
}


/**
 *	The About Author Section
 */
if ( !function_exists('itpg_about_author') ) {
	
	function itpg_about_author( $post ) { ?>
		<div id="author_box" class="row no-gutters">
			<div class="author_avatar col-md-2">
				<?php echo get_avatar( intval($post->post_author), apply_filters( 'itpg_avatar_size', 150 ) ); ?>
			</div>
			<div class="author_info col-md-10">
				<h4 class="author_name title-font">
					<?php echo get_the_author_meta( 'display_name', intval($post->post_author) ); ?>
				</h4>
				<div class="author_bio">
					<?php echo get_the_author_meta( 'description', intval($post->post_author) ); ?>
				</div>
			</div>
		</div>
	<?php
	}
	
}

 /**
  *	Function to add featured Areas before Content
  */
if ( !function_exists('itpg_get_sidebar_before_content') ) {
	function itpg_get_sidebar_before_content() {
		
		if ( is_front_page() && is_active_sidebar('before-content') ) :
			?>
			<div id="itpg-before-content" class="container">
				<?php
					dynamic_sidebar('before-content');
				?>
			</div>
			<?php
		endif;
	}
}
add_action('itpg_before_content', 'itpg_get_sidebar_before_content', 50);



/**
*	Function to add Featured Areas After Content
*/
   if ( !function_exists('itpg_get_after_content') ) {
function itpg_get_after_content() {

	    if ( is_front_page() && is_active_sidebar('after-content') ) :
			?>
			<div id="itpg-after-content" class="container">
				<?php
					dynamic_sidebar('after-content');
				?>
			</div>
			<?php
		endif;
   }
}
add_action('itpg_after_content', 'itpg_get_after_content');


/**
 *	Social Icons Footer Section
 */
 
function itpg_social_icons_footer() {
	
	get_template_part('framework/footer/social');
	
}
add_action('itpg_footer', 'itpg_social_icons_footer', 4);


/**
 *	Function for footer section
 */
if ( !function_exists('itpg_get_contact_info') ) {
	function itpg_get_contact_info() {
		
		if ( empty( get_theme_mod( 'itpg_footer_contact_enable' ) ) ) {
			return;
		}
		
		get_template_part( 'framework/footer/contact', 'info' );
		
	}
}
add_action('itpg_footer', 'itpg_get_contact_info', 5);



if ( !function_exists('itpg_get_footer_sidebars') ) {
	function itpg_get_footer_sidebars() {
		 
		$path 	=	'/framework/footer/footer';
		get_template_part( $path, get_theme_mod( 'itpg_footer_cols', 4 ) );
	}
}
add_action('itpg_footer', 'itpg_get_footer_sidebars', 10);
   


/**
 *	Related Posts of a Single Post
 */
 
function itpg_get_related_posts() {
	
	if ( get_post_type() == 'jetpack-portfolio' || get_post_type() == 'jetpack-testimonial' ) {
		return;
	}
	
	global $post;
	
	$related_args = apply_filters( 'itpg_related_posts_args', [
		"posts_per_page"		=>	3,
		"ignore_sticky_posts"	=>	true,
		"post__not_in"			=>	[get_the_ID()],
		"category_name"			=>	get_the_category($post)[0]->slug,
		"orderby"				=> "rand"
	] );
	
	$related_query	=	new WP_Query( $related_args );
	
	if ( $related_query->have_posts() ) : ?>
		<div id="itpg_related_posts_wrapper">
			<h2 id="itpg_related_posts_title"><?php _e('Related Posts', 'it-photographer'); ?></h2>
			<div class="itpg-related-posts row no-gutters">
				<?php
					while ( $related_query->have_posts() ) : $related_query->the_post();
			
						get_template_part( 'framework/layouts/content', 'related' );
						
					endwhile;
				?>
			</div>
		</div>
	<?php
	endif;
	wp_reset_postdata();
}
add_action('itpg_related_posts', 'itpg_get_related_posts');





/**
 *	The Hero Section Content
 */

function itpg_get_hero_content( $post, $length = 100 ) {
	
	$_post = get_post( $post );
	
	$output = '';
	
	if ( isset( $_post->post_content ) ) {
			
		if ( strpos($_post->post_content, '<!--more-->') ) {
			$output	=	strip_tags( get_the_content('', false, $_post ) );
		}
		else {
			
			$output	=	wp_trim_words( strip_shortcodes( $_post->post_content ), $length );
		}
	}
	
	echo $output;
}


// Filter search form
function itpg_nav_search( $form ) {
	
	$form = '<form role="search" method="get" class="search-form" action="' . esc_url( home_url( '/' ) ) . '">
                <label>
                    <span class="screen-reader-text">' . _x( 'Search for:', 'label', 'it-photographer' ) . '</span>
                    <input type="search" class="search-field" placeholder="' . esc_attr_x( 'Search &hellip;', 'placeholder', 'it-photographer' ) . '" value="' . get_search_query() . '" name="s" />
                </label>
            </form>';
            
            return $form;
            
}
add_filter( 'get_search_form', 'itpg_nav_search', 10, 1);